summaryrefslogtreecommitdiffhomepage
path: root/src/rlgl.h
diff options
context:
space:
mode:
authorRay <[email protected]>2015-12-24 12:42:48 +0100
committerRay <[email protected]>2015-12-24 12:42:48 +0100
commite8c79f53a67d3477a9780ac348410f1502467176 (patch)
treef51d6412b2064c555dcb1426d1775fb3b2d49558 /src/rlgl.h
parent1b39b2e2612dfd7613e3bfb6948e8d27472ab8c1 (diff)
parente683fe88b9ab0fde76521a0367cdff4c229ac60c (diff)
downloadraylib-e8c79f53a67d3477a9780ac348410f1502467176.tar.gz
raylib-e8c79f53a67d3477a9780ac348410f1502467176.zip
Merge pull request #66 from victorfisac/develop
New matrix location points, lighting and physics engine modules with examples
Diffstat (limited to 'src/rlgl.h')
-rw-r--r--src/rlgl.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/rlgl.h b/src/rlgl.h
index 0960fa83..a7df043e 100644
--- a/src/rlgl.h
+++ b/src/rlgl.h
@@ -160,7 +160,9 @@ typedef enum { OPENGL_11 = 1, OPENGL_33, OPENGL_ES_20 } GlVersion;
// Uniforms
int projectionLoc; // Projection matrix uniform location point (vertex shader)
- int modelviewLoc; // ModeView matrix uniform location point (vertex shader)
+ int modelviewLoc; // ModelView matrix uniform location point (vertex shader)
+ int modelLoc; // Model transformation matrix uniform location point (vertex shader)
+ int viewLoc; // View transformation matrix uniform location point (vertex shader)
int tintColorLoc; // Color uniform location point (fragment shader)
int mapDiffuseLoc; // Diffuse map texture uniform location point (fragment shader)